==> zio-aws-amplifybackend_2.12-5.17.126.2-sources.jar: zio/aws/amplifybackend/model/UpdateBackendAuthUserPoolConfig.scala <==
package zio.aws.amplifybackend.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateBackendAuthUserPoolConfig(
    forgotPassword: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthForgotPasswordConfig
    ] = None,
    mfa: Option[zio.aws.amplifybackend.model.UpdateBackendAuthMFAConfig] = None,
    oAuth: Option[zio.aws.amplifybackend.model.UpdateBackendAuthOAuthConfig] =
      None,
    passwordPolicy: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthPasswordPolicyConfig
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.UpdateBackendAuthUserPoolConfig = {
    import UpdateBackendAuthUserPoolConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.UpdateBackendAuthUserPoolConfig
      .builder()
      .optionallyWith(forgotPassword.map(value => value.buildAwsValue()))(
        _.forgotPassword
      )
      .optionallyWith(mfa.map(value => value.buildAwsValue()))(_.mfa)
      .optionallyWith(oAuth.map(value => value.buildAwsValue()))(_.oAuth)
      .optionallyWith(passwordPolicy.map(value => value.buildAwsValue()))(
        _.passwordPolicy
      )
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig.ReadOnly =
    zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig
      .wrap(buildAwsValue())
}
object UpdateBackendAuthUserPoolConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.UpdateBackendAuthUserPoolConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig =
      zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig(
        forgotPassword.map(value => value.asEditable),
        mfa.map(value => value.asEditable),
        oAuth.map(value => value.asEditable),
        passwordPolicy.map(value => value.asEditable)
      )
    def forgotPassword: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthForgotPasswordConfig.ReadOnly
    ]
    def mfa: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthMFAConfig.ReadOnly
    ]
    def oAuth: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthOAuthConfig.ReadOnly
    ]
    def passwordPolicy: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthPasswordPolicyConfig.ReadOnly
    ]
    def getForgotPassword: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.UpdateBackendAuthForgotPasswordConfig.ReadOnly
    ] = AwsError.unwrapOptionField("forgotPassword", forgotPassword)
    def getMfa: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.UpdateBackendAuthMFAConfig.ReadOnly
    ] = AwsError.unwrapOptionField("mfa", mfa)
    def getOAuth: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.UpdateBackendAuthOAuthConfig.ReadOnly
    ] = AwsError.unwrapOptionField("oAuth", oAuth)
    def getPasswordPolicy: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.UpdateBackendAuthPasswordPolicyConfig.ReadOnly
    ] = AwsError.unwrapOptionField("passwordPolicy", passwordPolicy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.UpdateBackendAuthUserPoolConfig
  ) extends zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig.ReadOnly {
    override val forgotPassword: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthForgotPasswordConfig.ReadOnly
    ] = scala
      .Option(impl.forgotPassword())
      .map(value =>
        zio.aws.amplifybackend.model.UpdateBackendAuthForgotPasswordConfig
          .wrap(value)
      )
    override val mfa: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthMFAConfig.ReadOnly
    ] = scala
      .Option(impl.mfa())
      .map(value =>
        zio.aws.amplifybackend.model.UpdateBackendAuthMFAConfig.wrap(value)
      )
    override val oAuth: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthOAuthConfig.ReadOnly
    ] = scala
      .Option(impl.oAuth())
      .map(value =>
        zio.aws.amplifybackend.model.UpdateBackendAuthOAuthConfig.wrap(value)
      )
    override val passwordPolicy: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthPasswordPolicyConfig.ReadOnly
    ] = scala
      .Option(impl.passwordPolicy())
      .map(value =>
        zio.aws.amplifybackend.model.UpdateBackendAuthPasswordPolicyConfig
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.UpdateBackendAuthUserPoolConfig
  ): zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifybackend_2.13-5.17.158.4-sources.jar: zio/aws/amplifybackend/model/UpdateBackendAuthUserPoolConfig.scala <==
package zio.aws.amplifybackend.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateBackendAuthUserPoolConfig(
    forgotPassword: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthForgotPasswordConfig
    ] = None,
    mfa: Option[zio.aws.amplifybackend.model.UpdateBackendAuthMFAConfig] = None,
    oAuth: Option[zio.aws.amplifybackend.model.UpdateBackendAuthOAuthConfig] =
      None,
    passwordPolicy: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthPasswordPolicyConfig
    ] = None,
    verificationMessage: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthVerificationMessageConfig
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.UpdateBackendAuthUserPoolConfig = {
    import UpdateBackendAuthUserPoolConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.UpdateBackendAuthUserPoolConfig
      .builder()
      .optionallyWith(forgotPassword.map(value => value.buildAwsValue()))(
        _.forgotPassword
      )
      .optionallyWith(mfa.map(value => value.buildAwsValue()))(_.mfa)
      .optionallyWith(oAuth.map(value => value.buildAwsValue()))(_.oAuth)
      .optionallyWith(passwordPolicy.map(value => value.buildAwsValue()))(
        _.passwordPolicy
      )
      .optionallyWith(verificationMessage.map(value => value.buildAwsValue()))(
        _.verificationMessage
      )
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig.ReadOnly =
    zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig
      .wrap(buildAwsValue())
}
object UpdateBackendAuthUserPoolConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.UpdateBackendAuthUserPoolConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig =
      zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig(
        forgotPassword.map(value => value.asEditable),
        mfa.map(value => value.asEditable),
        oAuth.map(value => value.asEditable),
        passwordPolicy.map(value => value.asEditable),
        verificationMessage.map(value => value.asEditable)
      )
    def forgotPassword: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthForgotPasswordConfig.ReadOnly
    ]
    def mfa: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthMFAConfig.ReadOnly
    ]
    def oAuth: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthOAuthConfig.ReadOnly
    ]
    def passwordPolicy: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthPasswordPolicyConfig.ReadOnly
    ]
    def verificationMessage: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthVerificationMessageConfig.ReadOnly
    ]
    def getForgotPassword: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.UpdateBackendAuthForgotPasswordConfig.ReadOnly
    ] = AwsError.unwrapOptionField("forgotPassword", forgotPassword)
    def getMfa: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.UpdateBackendAuthMFAConfig.ReadOnly
    ] = AwsError.unwrapOptionField("mfa", mfa)
    def getOAuth: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.UpdateBackendAuthOAuthConfig.ReadOnly
    ] = AwsError.unwrapOptionField("oAuth", oAuth)
    def getPasswordPolicy: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.UpdateBackendAuthPasswordPolicyConfig.ReadOnly
    ] = AwsError.unwrapOptionField("passwordPolicy", passwordPolicy)
    def getVerificationMessage: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.UpdateBackendAuthVerificationMessageConfig.ReadOnly
    ] = AwsError.unwrapOptionField("verificationMessage", verificationMessage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.UpdateBackendAuthUserPoolConfig
  ) extends zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig.ReadOnly {
    override val forgotPassword: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthForgotPasswordConfig.ReadOnly
    ] = scala
      .Option(impl.forgotPassword())
      .map(value =>
        zio.aws.amplifybackend.model.UpdateBackendAuthForgotPasswordConfig
          .wrap(value)
      )
    override val mfa: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthMFAConfig.ReadOnly
    ] = scala
      .Option(impl.mfa())
      .map(value =>
        zio.aws.amplifybackend.model.UpdateBackendAuthMFAConfig.wrap(value)
      )
    override val oAuth: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthOAuthConfig.ReadOnly
    ] = scala
      .Option(impl.oAuth())
      .map(value =>
        zio.aws.amplifybackend.model.UpdateBackendAuthOAuthConfig.wrap(value)
      )
    override val passwordPolicy: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthPasswordPolicyConfig.ReadOnly
    ] = scala
      .Option(impl.passwordPolicy())
      .map(value =>
        zio.aws.amplifybackend.model.UpdateBackendAuthPasswordPolicyConfig
          .wrap(value)
      )
    override val verificationMessage: Option[
      zio.aws.amplifybackend.model.UpdateBackendAuthVerificationMessageConfig.ReadOnly
    ] = scala
      .Option(impl.verificationMessage())
      .map(value =>
        zio.aws.amplifybackend.model.UpdateBackendAuthVerificationMessageConfig
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.UpdateBackendAuthUserPoolConfig
  ): zio.aws.amplifybackend.model.UpdateBackendAuthUserPoolConfig.ReadOnly =
    new Wrapper(impl)
}
